@@ -39,7 +39,7 @@ my $useioctl = 1;
 ## while writing this), and for Roland Schemers whose line_edit.pl I used
 ## as an early basis for this.
 ##
-$VERSION = $VERSION = 0.9903;
+$VERSION = $VERSION = 0.9906;
 
 ## 940817.008 - Added $var_CompleteAddsuffix.
 ##		Now recognizes window-change signals (at least on BSD).
@@ -86,6 +86,8 @@ $VERSION = $VERSION = 0.9903;
 ## Reload-init-file moved to C-x C-x.
 ## C-x ? and C-x * list/insert possible completions.
 
+$rl_getc = \&rl_getc;
+
 &preinit;
 &init;
 
@@ -810,7 +812,7 @@ sub F_ReReadInitFile
 
     while (<RC>) {
 	s/^\s*//;
-	next if m/^#/;
+	next if m/^\s*(#|$)/;
 	$InputLocMsg = " [$file line $.]";
 	if (/^\$if\s+/) {
 	    my($test) = $';
@@ -957,7 +959,7 @@ sub readline
     while (!defined($AcceptLine)) {
 	## get a character of input
 	if (!defined($pending)) {
-	    $input = rl_getc(); # bug in debugger, returns 42. - No more!
+	    $input = &$rl_getc(); # bug in debugger, returns 42. - No more!
 	} else {
 	    $input = substr($pending, 0, 1);
 	    substr($pending, 0, 1) = '';
@@ -1063,15 +1065,18 @@ sub substr_with_props {
   defined $from or $from = 0;
   defined $len or $len = length($p) + length($s) - $from;
 
+  $p =~ s/^(\s*)//; my $bs = $1;
+  $p =~ s/(\s*)$//; my $as = $1;
+
   if ($from >= $lp) {
     return $rl_term_set->[2] . substr($s, $from - $lp, $len) 
       . $rl_term_set->[3];
   } elsif ($from + $len <= $lp) {
-    return $rl_term_set->[0] . substr($prompt, $from, $len) 
-      . $rl_term_set->[1];
+    return $bs . $rl_term_set->[0] . substr($p, $from, $len) 
+      . $rl_term_set->[1] . $as;
   } else {
-    return $rl_term_set->[0] . substr($prompt, $from, $lp - $from) 
-      . $rl_term_set->[1]
+    return $bs . $rl_term_set->[0] . substr($p, $from, $lp - $from) 
+      . $rl_term_set->[1] . $as
 	. $rl_term_set->[2] . substr($s, 0, $from + $len - $lp) 
 	  . $rl_term_set->[3];
   }
@@ -1735,7 +1740,7 @@ sub F_ClearScreen
 sub F_QuotedInsert
 {
     my $count = shift;
-    &F_SelfInsert($count, ord(rl_getc));
+    &F_SelfInsert($count, ord(&$rl_getc));
 }
 
 ##
@@ -1973,7 +1978,7 @@ sub search {
 
 sub DoSearch
 {
-    my $reverse = shift;
+    local $reverse = shift;	# Used in search()
     my $oldline = $line;
     my $oldD = $D;
 
@@ -1985,12 +1990,12 @@ sub DoSearch
     while (1)
     {
 	if ($I != -1) {
-	    $line .= $rl_History[$I];
+	    $line = $rl_History[$I];
 	    $D += index($rl_History[$I], $searchstr);
 	}
 	&redisplay( '('.($reverse?'reverse-':'') ."i-search) `$searchstr': ");
 
-	$c = rl_getc;
+	$c = &$rl_getc;
 	if ($KeyMap[ord($c)] eq 'F_ReverseSearchHistory') {
 	    if ($reverse && $I != -1) {
 		if ($tmp = &search($I-1,$searchstr), $tmp >= 0) {
@@ -2231,7 +2236,7 @@ sub F_PrefixMeta
     my($count, $keymap) = ($_[0], "$KeyMap{'name'}_$_[1]");
     ##print "F_PrefixMeta [$keymap]\n\r";
     die "<internal error, $_[1]>" unless defined(%$keymap);
-    do_command(*$keymap, $count, ord(rl_getc));
+    do_command(*$keymap, $count, ord(&$rl_getc));
 }
 
 sub F_UniversalArgument
@@ -2276,7 +2281,7 @@ sub F_DigitArgument
 	    $NumericArg = -$rl_max_numeric_arg;
 	}
 	&redisplay(sprintf("(arg %d) ", $NumericArg));
-    } while $ord = ord(rl_getc);
+    } while $ord = ord(&$rl_getc);
 }
 
 sub F_OverwriteMode
@@ -2601,7 +2606,7 @@ sub pretty_print_list
     $columns = $maxwidth >= $rl_screen_width
 	       ? 1 : int($rl_screen_width / $maxwidth);
 
-    ## if there's enough margin to interspurse among the columsn, do so.
+    ## if there's enough margin to interspurse among the columns, do so.
     $maxwidth += int(($rl_screen_width % $maxwidth) / $columns);
 
     $lines = int((@list + $columns - 1) / $columns);
